# sage_setup: distribution = sagemath-repl
"""
This file (./recequadiff_doctest.sage) was *autogenerated* from ./recequadiff.tex,
with sagetex.sty version 2011/05/27 v2.3.1.
It contains the contents of all the sageexample environments from this file.
You should be able to doctest this file with:
sage -t ./recequadiff_doctest.sage
It is always safe to delete this file; it is not used in typesetting your
document.

Sage example in ./recequadiff.tex, line 182::

  sage: x = var('x')
  sage: y = function('y')(x)

Sage example in ./recequadiff.tex, line 295::

  sage: x = var('x'); y = function('y')(x)

Sage example in ./recequadiff.tex, line 298::

  sage: desolve(diff(y,x) + 3*y == exp(x), y, show_method=True)
  [1/4*(4*_C + e^(4*x))*e^(-3*x), 'linear']

Sage example in ./recequadiff.tex, line 320::

  sage: desolve(y*diff(y,x) == x, y, show_method=True)
  [1/2*y(x)^2 == 1/2*x^2 + _C, 'separable']

Sage example in ./recequadiff.tex, line 332::

  sage: desolve(diff(y,x) == exp(x+y), y, show_method=True)
  [-(e^(x + y(x)) + 1)*e^(-y(x)) == _C, 'exact']

Sage example in ./recequadiff.tex, line 350::

  sage: desolve(diff(y,x)-y == x*y^4, y, show_method=True)
  [e^x/(-1/3*(3*x - 1)*e^(3*x) + _C)^(1/3), 'bernoulli']

Sage example in ./recequadiff.tex, line 371::

  sage: desolve(x^2*diff(y,x) == y^2+x*y+x^2, y, show_method=True)
  [_C*x == e^(arctan(y(x)/x)), 'homogeneous']

Sage example in ./recequadiff.tex, line 399::

  sage: desolve(diff(y,x) == (cos(y)-2*x)/(y+x*sin(y)), y,
  ....:         show_method=True)
  [x^2 - x*cos(y(x)) + 1/2*y(x)^2 == _C, 'exact']

Sage example in ./recequadiff.tex, line 431::

  sage: desolve(diff(y,x) == x*y^2+y/x-1/x^2, y,
  ....:         contrib_ode=True, show_method=True)[1]
  'riccati'

Sage example in ./recequadiff.tex, line 459::

  sage: diffeq = y == x*diff(y,x)-diff(y,x)^2
  sage: solution,method = desolve(diffeq,
  ....:                           y,
  ....:                           contrib_ode=True,
  ....:                           show_method=True)
  sage: solution
  [y(x) == -_C^2 + _C*x, y(x) == 1/4*x^2]
  sage: method in ["clairaut", "clairault"]
  True

Sage example in ./recequadiff.tex, line 487::

  sage: x = var('x'); y = function('y')(x)

Sage example in ./recequadiff.tex, line 491::

  sage: DE = diff(y,x)+2*y == x**2-2*x+3
  sage: desolve(DE, y)
  1/4*((2*x^2 - 2*x + 1)*e^(2*x) - 2*(2*x - 1)*e^(2*x) + 4*_C
  + 6*e^(2*x))*e^(-2*x)

Sage example in ./recequadiff.tex, line 499::

  sage: desolve(DE, y).expand()
  1/2*x^2 + _C*e^(-2*x) - 3/2*x + 9/4

Sage example in ./recequadiff.tex, line 518::

  sage: desolve(DE, y, show_method=True)[1]
  'linear'

Sage example in ./recequadiff.tex, line 526::

  sage: desolve(DE, y, ics=[0,1]).expand()
  1/2*x^2 - 3/2*x - 5/4*e^(-2*x) + 9/4

Sage example in ./recequadiff.tex, line 541::

  sage: x = var('x'); y = function('y')(x)
  sage: desolve(diff(y,x)*log(y) == y*sin(x), y, show_method=True)
  [1/2*log(y(x))^2 == _C - cos(x), 'separable']

Sage example in ./recequadiff.tex, line 552::

  sage: ed = desolve(diff(y,x)*log(y) == y*sin(x), y); ed
  1/2*log(y(x))^2 == _C - cos(x)

Sage example in ./recequadiff.tex, line 565::

  sage: solve(ed, y)
  [y(x) == e^(-sqrt(2*_C - 2*cos(x))), y(x) == e^(sqrt(2*_C - 2*cos(x)))]

Sage example in ./recequadiff.tex, line 581::

  sage: solve(ed, y)[0].substitute(_C==5).rhs()
  Traceback (most recent call last):
  ...
  NameError: name '_C' is not defined

Sage example in ./recequadiff.tex, line 593::

  sage: ed.variables()
  (_C, x)

Sage example in ./recequadiff.tex, line 604::

  sage: c = ed.variables()[0]
  sage: solve(ed, y)[0].substitute(c == 5).rhs()
  e^(-sqrt(-2*cos(x) + 10))

Sage example in ./recequadiff.tex, line 624::

  sage: plot(solve(ed, y)[0].substitute(c == 2).rhs(), x, -3, 3)
  Graphics object consisting of 1 graphics primitive

Sage example in ./recequadiff.tex, line 640::

  sage: P = Graphics()
  sage: for k in range(1,20,2):
  ....:     P += plot(solve(ed, y)[0].substitute(c==1+k/4).rhs(), x, -3, 3)

Sage example in ./recequadiff.tex, line 660::

  sage: P = Graphics()
  sage: for j in [0,1]:
  ....:     for k in range(1,10,2):
  ....:         f = solve(ed,y)[j].substitute(c==2+0.25*k).rhs()
  ....:         P += plot(f, x, -3, 3)
  sage: P
  Graphics object consisting of 10 graphics primitives

Sage example in ./recequadiff.tex, line 731::

  sage: u = function('u')(x)
  sage: y = x*u
  sage: DE = x*diff(y,x) == y + sqrt(x**2 + y**2)

Sage example in ./recequadiff.tex, line 746::

  sage: forget()

Sage example in ./recequadiff.tex, line 750::

  sage: assume(x>0)
  sage: desolve(DE, u)
  x == _C*e^arcsinh(u(x))

Sage example in ./recequadiff.tex, line 773::

  sage: S = desolve(DE,u)._maxima_().ev(logarc=True).sage().solve(u); S
  [u(x) == -(sqrt(u(x)^2 + 1)*_C - x)/_C]

Sage example in ./recequadiff.tex, line 792::

  sage: solu = (x-S[0]*c)^2; solu
  (_C*u(x) - x)^2 == (u(x)^2 + 1)*_C^2
  sage: sol = solu.solve(u); sol
  [u(x) == -1/2*(_C^2 - x^2)/(_C*x)]

Sage example in ./recequadiff.tex, line 801::

  sage: y(x) = x*sol[0].rhs(); y(x)
  -1/2*(_C^2 - x^2)/_C

Sage example in ./recequadiff.tex, line 820::

  sage: c = y(x).variables()[0]
  sage: P = Graphics()
  sage: for k in range(-19,19,2):
  ....:     P += plot(y(x).substitute(c == 1/k), x, 0, 3)
  sage: P
  Graphics object consisting of 19 graphics primitives

Sage example in ./recequadiff.tex, line 870::

  sage: x = var('x'); y = function('y')(x); a, b = var('a, b')
  sage: DE = diff(y,x) - a*y == -b*y**2
  sage: sol = desolve(DE,[y,x]); sol
  -(log(b*y(x) - a) - log(y(x)))/a == _C + x

Sage example in ./recequadiff.tex, line 880::

  sage: Sol = solve(sol, y)[0]; Sol
  log(y(x)) == _C*a + a*x + log(b*y(x) - a)

Sage example in ./recequadiff.tex, line 892::

  sage: Sol(x) = Sol.lhs()-Sol.rhs(); Sol(x)
  -_C*a - a*x - log(b*y(x) - a) + log(y(x))
  sage: Sol = Sol.simplify_log(); Sol(x)
  -_C*a - a*x + log(y(x)/(b*y(x) - a))
  sage: solve(Sol, y)[0].simplify()
  y(x) == a*e^(_C*a + a*x)/(b*e^(_C*a + a*x) - 1)

Sage example in ./recequadiff.tex, line 928::

  sage: x = var('x'); y = function('y')(x)
  sage: DE = diff(y,x,2)+3*y == x^2-7*x+31
  sage: desolve(DE, y).expand()
  1/3*x^2 + _K2*cos(sqrt(3)*x) + _K1*sin(sqrt(3)*x) - 7/3*x + 91/9

Sage example in ./recequadiff.tex, line 938::

  sage: desolve(DE, y, ics=[0,1,2]).expand()
  1/3*x^2 + 13/9*sqrt(3)*sin(sqrt(3)*x) - 7/3*x - 82/9*cos(sqrt(3)*x) + 91/9

Sage example in ./recequadiff.tex, line 948::

  sage: desolve(DE, y, ics=[0,1,-1,0]).expand()
  1/3*x^2 - 7/3*x - 82/9*cos(sqrt(3))*sin(sqrt(3)*x)/sin(sqrt(3))
  + 115/9*sin(sqrt(3)*x)/sin(sqrt(3)) - 82/9*cos(sqrt(3)*x) + 91/9

Sage example in ./recequadiff.tex, line 1022::

  sage: x, t = var('x, t'); f = function('f')(x); g = function('g')(t)
  sage: z = f*g
  sage: eq(x,t) = diff(z,x,2) == diff(z,t); eq(x,t)
  g(t)*diff(f(x), x, x) == f(x)*diff(g(t), t)

Sage example in ./recequadiff.tex, line 1042::

  sage: eqn = eq/z; eqn(x,t)
  diff(f(x), x, x)/f(x) == diff(g(t), t)/g(t)

Sage example in ./recequadiff.tex, line 1061::

  sage: k = var('k')
  sage: eq1(x,t) = eqn(x,t).lhs() == k; eq2(x,t) = eqn(x,t).rhs() == k

Sage example in ./recequadiff.tex, line 1069::

  sage: g(t) = desolve(eq2(x,t),[g,t]); g(t)
  _C*e^(k*t)

Sage example in ./recequadiff.tex, line 1092::

  sage: assume(k>0); desolve(eq1,[f,x])
  _K1*e^(sqrt(k)*x) + _K2*e^(-sqrt(k)*x)

Sage example in ./recequadiff.tex, line 1176::

  sage: x, s = var('x, s'); f = function('f')(x)
  sage: f(x) = sin(x); f.laplace(x,s)
  x |--> 1/(s^2 + 1)

Sage example in ./recequadiff.tex, line 1191::

  sage: X(s) = 1/(s^2-3*s-4)/(s^2+1) + (s-4)/(s^2-3*s-4)
  sage: X(s).inverse_laplace(s, x)
  3/34*cos(x) + 1/85*e^(4*x) + 9/10*e^(-x) - 5/34*sin(x)

Sage example in ./recequadiff.tex, line 1206::

  sage: X(s).partial_fraction()
  1/34*(3*s - 5)/(s^2 + 1) + 9/10/(s + 1) + 1/85/(s - 4)

Sage example in ./recequadiff.tex, line 1221::

  sage: x = var('x'); y = function('y')(x)
  sage: eq = diff(y,x,x) - 3*diff(y,x) - 4*y - sin(x) == 0
  sage: desolve_laplace(eq, y)
  1/85*(17*y(0) + 17*D[0](y)(0) + 1)*e^(4*x) + 1/10*(8*y(0)
  - 2*D[0](y)(0) - 1)*e^(-x) + 3/34*cos(x) - 5/34*sin(x)
  sage: desolve_laplace(eq, y, ics=[0,1,-1])
  3/34*cos(x) + 1/85*e^(4*x) + 9/10*e^(-x) - 5/34*sin(x)

Sage example in ./recequadiff.tex, line 1279::

  sage: x = var('x'); y1 = function('y1')(x)
  sage: y2 = function('y2')(x); y3 = function('y3')(x)
  sage: y = vector([y1, y2, y3])
  sage: A = matrix([[2,-2,0],[-2,0,2],[0,2,2]])
  sage: system = [diff(y[i], x) - (A * y)[i] for i in range(3)]
  sage: desolve_system(system, [y1, y2, y3], ics=[0,2,1,-2])
  [y1(x) == e^(4*x) + e^(-2*x),
   y2(x) == -e^(4*x) + 2*e^(-2*x),
   y3(x) == -e^(4*x) - e^(-2*x)]

Sage example in ./recequadiff.tex, line 1328::

  sage: x = var('x'); y1 = function('y1')(x); y2 = function('y2')(x)
  sage: y = vector([y1,y2])
  sage: A = matrix([[3,-4],[1,3]])
  sage: system = [diff(y[i], x) - (A * y)[i] for i in range(2)]
  sage: desolve_system(system, [y1, y2], ics=[0,2,0])
  [y1(x) == 2*cos(2*x)*e^(3*x), y2(x) == e^(3*x)*sin(2*x)]

Sage example in ./recequadiff.tex, line 1385::

  sage: x = var('x'); u1 = function('u1')(x); u2 = function('u2')(x)
  sage: u3 = function('u3')(x); u4 = function('u4')(x)
  sage: u = vector([u1,u2,u3,u4])
  sage: A = matrix([[0,0,1,0],[0,0,0,1],[2,-6,1,3],[-2,6,1,-1]])
  sage: system = [diff(u[i], x) - (A*u)[i] for i in range(4)]
  sage: sol = desolve_system(system, [u1, u2, u3, u4])

Sage example in ./recequadiff.tex, line 1399::

  sage: sol[0]
  u1(x) == 1/12*(2*u1(0) - 6*u2(0) + 5*u3(0) + 3*u4(0))*e^(2*x)
  + 1/24*(2*u1(0) - 6*u2(0) - u3(0) + 3*u4(0))*e^(-4*x) + 3/4*u1(0)
  + 3/4*u2(0) - 3/8*u3(0) - 3/8*u4(0)
  sage: sol[1]
  u2(x) == -1/12*(2*u1(0) - 6*u2(0) - u3(0) - 3*u4(0))*e^(2*x)
  - 1/24*(2*u1(0) - 6*u2(0) - u3(0) + 3*u4(0))*e^(-4*x) + 1/4*u1(0)
  + 1/4*u2(0) - 1/8*u3(0) - 1/8*u4(0)

Sage example in ./recequadiff.tex, line 1557::

  sage: x = var('x'); f = function('f')(x)
  sage: f(x) = 3.83*x*(1 - x/100000)
  sage: def u(n):
  ....:     if n==0: return(20000)
  ....:     else: return f(u(n-1))

Sage example in ./recequadiff.tex, line 1568::

  sage: def v(n):
  ....:     V = 20000;
  ....:     for k in [1..n]:
  ....:         V = f(V)
  ....:     return V

Sage example in ./recequadiff.tex, line 1582::

  sage: def cloud(u, n):
  ....:     L = [[0,u(0)]];
  ....:     for k in [1..n]:
  ....:         L += [[k,u(k)]]
  ....:     points(L).show()

Sage example in ./recequadiff.tex, line 1598::

  sage: cloud(u,50)

Sage example in ./recequadiff.tex, line 1619::

  sage: def snail(f, x, u0, n, xmin, xmax):
  ....:     u = u0
  ....:     P = plot(x, x, xmin, xmax, color='gray')
  ....:     for i in range(n):
  ....:         P += line([[u,u],[u,f(u)],[f(u),f(u)]], color = 'red')
  ....:         u = f(u)
  ....:     P += f.plot(x, xmin, xmax, color='blue')
  ....:     P.show()

Sage example in ./recequadiff.tex, line 1637::

  sage: f(x) = 3.83*x*(1 - x/100000)
  sage: snail(f,x,20000,100,0,100000)

Sage example in ./recequadiff.tex, line 1687::

  sage: from sympy import Function
  sage: from sympy.abc import n
  sage: u = Function('u')

Sage example in ./recequadiff.tex, line 1700::

  sage: f = u(n+2)-(3/2)*u(n+1)+(1/2)*u(n)

Sage example in ./recequadiff.tex, line 1707::

  sage: from sympy import rsolve
  sage: rsolve(f, u(n), {u(0):-1,u(1):1}) == 3 - 4*2**(-n)
  True

Sage example in ./recequadiff.tex, line 1798::

  sage: from sympy import rsolve_hyper
  sage: from sympy.abc import n
  sage: rsolve_hyper([-2,1],2**(n+2),n)
  2**n*C0 + 2**(n + 1)*n
"""



# sage_setup: distribution = sagemath-repl
##          Sage Doctest File         ##
#**************************************#
#*    Generated from PreTeXt source   *#
#*    on 2017-08-24T11:43:34-07:00    *#
#*                                    *#
#*   http://mathbook.pugetsound.edu   *#
#*                                    *#
#**************************************#
##
"""
Please contact Rob Beezer (beezer@ups.edu) with
any test failures here that need to be changed
as a result of changes accepted into Sage.  You
may edit/change this file in any sensible way, so
that development work may procede.  Your changes
may later be replaced by the authors of "Abstract
Algebra: Theory and Applications" when the text is
updated, and a replacement of this file is proposed
for review.
"""
##
## To execute doctests in these files, run
##   $ $SAGE_ROOT/sage -t <directory-of-these-files>
## or
##   $ $SAGE_ROOT/sage -t <a-single-file>
##
## Replace -t by "-tp n" for parallel testing,
##   "-tp 0" will use a sensible number of threads
##
## See: http://www.sagemath.org/doc/developer/doctesting.html
##   or run  $ $SAGE_ROOT/sage --advanced  for brief help
##
## Generated at 2017-08-24T11:43:34-07:00
## From "Abstract Algebra"
## At commit 26d3cac0b4047f4b8d6f737542be455606e2c4b4
##
## Section 11.5 Sage
##
r"""
~~~~~~~~~~~~~~~~~~~~~~ ::

    sage: C12 = CyclicPermutationGroup(12)
    sage: C20 = CyclicPermutationGroup(20)
    sage: domain_gens = C12.gens()
    sage: [g.order() for g in domain_gens]
    [12]

~~~~~~~~~~~~~~~~~~~~~~ ::

    sage: x = C20.gen(0)
    sage: y = x^5
    sage: y.order()
    4

~~~~~~~~~~~~~~~~~~~~~~ ::

    sage: phi = PermutationGroupMorphism(C12, C20, [y])
    sage: phi
    Permutation group morphism:
      From: Cyclic group of order 12 as a permutation group
      To:   Cyclic group of order 20 as a permutation group
      Defn: [(1,2,3,4,5,6,7,8,9,10,11,12)] ->
            [(1,6,11,16)(2,7,12,17)(3,8,13,18)(4,9,14,19)(5,10,15,20)]

~~~~~~~~~~~~~~~~~~~~~~ ::

    sage: a = C12("(1,6,11,4,9,2,7,12,5,10,3,8)")
    sage: phi(a)
    (1,6,11,16)(2,7,12,17)(3,8,13,18)(4,9,14,19)(5,10,15,20)

~~~~~~~~~~~~~~~~~~~~~~ ::

    sage: b = C12("(1,3,5,7,9,11)(2,4,6,8,10,12)")
    sage: phi(b)
    (1,11)(2,12)(3,13)(4,14)(5,15)(6,16)(7,17)(8,18)(9,19)(10,20)

~~~~~~~~~~~~~~~~~~~~~~ ::

    sage: c = C12("(1,9,5)(2,10,6)(3,11,7)(4,12,8)")
    sage: phi(c)
    ()

~~~~~~~~~~~~~~~~~~~~~~ ::

    sage: K = phi.kernel(); K
    Subgroup generated by [(1,5,9)(2,6,10)(3,7,11)(4,8,12)]
    of (Cyclic group of order 12 as a permutation group)

~~~~~~~~~~~~~~~~~~~~~~ ::

    sage: Im = phi.image(C12); Im
    Subgroup generated by
    [(1,6,11,16)(2,7,12,17)(3,8,13,18)(4,9,14,19)(5,10,15,20)]
    of (Cyclic group of order 20 as a permutation group)

~~~~~~~~~~~~~~~~~~~~~~ ::

    sage: Im.is_isomorphic(C12.quotient(K))
    True

~~~~~~~~~~~~~~~~~~~~~~ ::

    sage: G = DihedralGroup(5)
    sage: H = DihedralGroup(20)
    sage: G.gens()
    ((1,2,3,4,5), (1,5)(2,4))

~~~~~~~~~~~~~~~~~~~~~~ ::

    sage: H.gens()
    ((1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20),
     (1,20)(2,19)(3,18)(4,17)(5,16)(6,15)(7,14)(8,13)(9,12)(10,11))

~~~~~~~~~~~~~~~~~~~~~~ ::

    sage: x = H.gen(0)^4
    sage: y = H.gen(1)
    sage: rho = PermutationGroupMorphism(G, H, [x, y])
    sage: rho.kernel()
    Subgroup generated by
    [()] of (Dihedral group of order 10 as a permutation group)

~~~~~~~~~~~~~~~~~~~~~~ ::

    sage: Im = rho.image(G); Im
    Subgroup generated by
    [(1,5,9,13,17)(2,6,10,14,18)(3,7,11,15,19)(4,8,12,16,20),
     (1,20)(2,19)(3,18)(4,17)(5,16)(6,15)(7,14)(8,13)(9,12)(10,11)]
    of (Dihedral group of order 40 as a permutation group)

~~~~~~~~~~~~~~~~~~~~~~ ::

    sage: Im.is_subgroup(H)
    True

~~~~~~~~~~~~~~~~~~~~~~ ::

    sage: Im.is_isomorphic(G)
    True

~~~~~~~~~~~~~~~~~~~~~~ ::

    sage: G = CyclicPermutationGroup(7)
    sage: H = CyclicPermutationGroup(4)
    sage: tau = PermutationGroupMorphism_im_gens(G, H, H.gens())
    sage: tau
    Permutation group morphism:
      From: Cyclic group of order 7 as a permutation group
      To:   Cyclic group of order 4 as a permutation group
      Defn: [(1,2,3,4,5,6,7)] -> [(1,2,3,4)]

~~~~~~~~~~~~~~~~~~~~~~ ::

    sage: tau.kernel()
    Traceback (most recent call last):
    ...
    sage.libs.gap.util.GAPError: Error, no method found! Error, no 1st choice method found for `Kernel' on 1 arguments
    The 1st argument is 'fail' which might point to an earlier problem

~~~~~~~~~~~~~~~~~~~~~~ ::

    sage: G = CyclicPermutationGroup(3)
    sage: H = DihedralGroup(4)
    sage: results = G.direct_product(H)
    sage: results[0]
    Permutation Group with generators [(1,2,3), (4,5,6,7), (4,7)(5,6)]

~~~~~~~~~~~~~~~~~~~~~~ ::

    sage: results[1]
    Permutation group morphism:
      From: Cyclic group of order 3 as a permutation group
      To:   Permutation Group with generators [(1,2,3), (4,5,6,7), (4,7)(5,6)]
      Defn: Embedding( Group( [ (1,2,3), (4,5,6,7), (4,7)(5,6) ] ), 1 )

~~~~~~~~~~~~~~~~~~~~~~ ::

    sage: results[2]
    Permutation group morphism:
      From: Dihedral group of order 8 as a permutation group
      To:   Permutation Group with generators [(1,2,3), (4,5,6,7), (4,7)(5,6)]
      Defn: Embedding( Group( [ (1,2,3), (4,5,6,7), (4,7)(5,6) ] ), 2 )

~~~~~~~~~~~~~~~~~~~~~~ ::

    sage: results[3]
    Permutation group morphism:
      From: Permutation Group with generators [(1,2,3), (4,5,6,7), (4,7)(5,6)]
      To:   Cyclic group of order 3 as a permutation group
      Defn: Projection( Group( [ (1,2,3), (4,5,6,7), (4,7)(5,6) ] ), 1 )

~~~~~~~~~~~~~~~~~~~~~~ ::

    sage: results[4]
    Permutation group morphism:
      From: Permutation Group with generators [(1,2,3), (4,5,6,7), (4,7)(5,6)]
      To:   Dihedral group of order 8 as a permutation group
      Defn: Projection( Group( [ (1,2,3), (4,5,6,7), (4,7)(5,6) ] ), 2 )
"""



# sage_setup: distribution = sagemath-repl
# sage.doctest: needs sage.all
r"""
TESTS:

Check that all non deprecated lazy imports resolve correctly. We avoid libgiac
on purpose because it does print stuff, see :issue:`31655`.::

    sage: from sage.misc.lazy_import import LazyImport
    sage: G = globals()
    sage: for name, obj in sorted(G.items()):
    ....:     if name == 'libgiac':
    ....:          continue
    ....:     if type(obj) is LazyImport and obj._get_deprecation_issue() == 0:
    ....:         try:
    ....:             _ = obj._get_object()
    ....:         except Exception as e:
    ....:             print('{} does not resolve: {}'.format(name, e))

Check that all deprecated lazy imports resolve correctly::

    sage: import warnings
    sage: for name, obj in sorted(G.items()):
    ....:     if type(obj) is LazyImport and obj._get_deprecation_issue() != 0:
    ....:         with warnings.catch_warnings(record=True) as w:
    ....:             _ = obj._get_object()
    ....:             assert w[0].category == DeprecationWarning
"""



# sage_setup: distribution = sagemath-repl
"""
This file (./combinat_doctest.sage) was *autogenerated* from ./combinat.tex,
with sagetex.sty version 2011/05/27 v2.3.1.
It contains the contents of all the sageexample environments from this file.
You should be able to doctest this file with:
sage -t ./combinat_doctest.sage
It is always safe to delete this file; it is not used in typesetting your
document.

Sage example in ./combinat.tex, line 147::

  sage: Suits = Set(["Hearts", "Diamonds", "Spades", "Clubs"])
  sage: Values = Set([2, 3, 4, 5, 6, 7, 8, 9, 10,
  ....:               "Jack", "Queen", "King", "Ace"])
  sage: Cards = cartesian_product([Values, Suits])

Sage example in ./combinat.tex, line 167::

  sage: Suits.cardinality()
  4
  sage: Values.cardinality()
  13
  sage: Cards.cardinality()
  52

Sage example in ./combinat.tex, line 184::

  sage: Cards.random_element()                      # random
  (6, 'Clubs')

Sage example in ./combinat.tex, line 196::

  sage: Set([Cards.random_element(), Cards.random_element()]) # random
  {(2, 'Hearts'), (4, 'Spades')}

Sage example in ./combinat.tex, line 221::

  sage: Hands = Subsets(Cards, 5)
  sage: Hands.random_element()                      # random
  {(4, 'Hearts'), (9, 'Diamonds'), (8, 'Spades'),
   (9, 'Clubs'), (7, 'Hearts')}

Sage example in ./combinat.tex, line 236::

  sage: binomial(52, 5)
  2598960

Sage example in ./combinat.tex, line 250::

  sage: Hands.cardinality()
  2598960

Sage example in ./combinat.tex, line 283::

  sage: Flushes = cartesian_product([Subsets(Values, 5), Suits])
  sage: Flushes.cardinality()
  5148

Sage example in ./combinat.tex, line 305::

  sage: Flushes.cardinality()  / Hands.cardinality()
  33/16660

Sage example in ./combinat.tex, line 310::

  sage: 1000.0 * Flushes.cardinality()  / Hands.cardinality()
  1.98079231692677

Sage example in ./combinat.tex, line 345::

  sage: def is_flush(hand):
  ....:     return len(set(suit for (val, suit) in hand)) == 1

Sage example in ./combinat.tex, line 354::

  sage: n = 10000
  sage: nflush = 0
  sage: for i in range(n):
  ....:    hand = Hands.random_element()
  ....:    if is_flush(hand):
  ....:        nflush += 1
  sage: print(n, nflush)                              # random
  10000, 18

Sage example in ./combinat.tex, line 600::

  sage: C, z = var('C, z'); sys = [ C == z + C*C ]

Sage example in ./combinat.tex, line 605::

  sage: sol = solve(sys, C, solution_dict=True); sol
  [{C: -1/2*sqrt(-4*z + 1) + 1/2}, {C: 1/2*sqrt(-4*z + 1) + 1/2}]
  sage: s0 = sol[0][C]; s1 = sol[1][C]

Sage example in ./combinat.tex, line 612::

  sage: s0.series(z, 6)
  1*z + 1*z^2 + 2*z^3 + 5*z^4 + 14*z^5 + Order(z^6)
  sage: s1.series(z, 6)
  1 + (-1)*z + (-1)*z^2 + (-2)*z^3 + (-5)*z^4 + (-14)*z^5 + Order(z^6)

Sage example in ./combinat.tex, line 622::

  sage: C = s0

Sage example in ./combinat.tex, line 627::

  sage: C.series(z, 11)
  1*z + 1*z^2 + 2*z^3 + 5*z^4 + 14*z^5 + 42*z^6 +
  132*z^7 + 429*z^8 + 1430*z^9 + 4862*z^10 + Order(z^11)

Sage example in ./combinat.tex, line 634::

  sage: C.series(z, 101).coefficient(z,100)
  227508830794229349661819540395688853956041682601541047340

Sage example in ./combinat.tex, line 654::

  sage: L.<z> = LazyPowerSeriesRing(QQ)

Sage example in ./combinat.tex, line 661::

  sage: C = L.undefined(valuation=1)
  sage: C.define( z + C * C )

Sage example in ./combinat.tex, line 666::

  sage: [C.coefficient(i) for i in range(11)]
  [0, 1, 1, 2, 5, 14, 42, 132, 429, 1430, 4862]

Sage example in ./combinat.tex, line 674::

  sage: C.coefficient(100)
  227508830794229349661819540395688853956041682601541047340

Sage example in ./combinat.tex, line 684::

  sage: C.coefficient(200)
  129013158064429114001222907669676675134349530552728882499810851598901419013348319045534580850847735528275750122188940

Sage example in ./combinat.tex, line 693::

  sage: z = var('z'); C = s0; C
  -1/2*sqrt(-4*z + 1) + 1/2

Sage example in ./combinat.tex, line 703::

  sage: derivative(C, z, 1)
  1/sqrt(-4*z + 1)
  sage: derivative(C, z, 2)
  2/(-4*z + 1)^(3/2)
  sage: derivative(C, z, 3)
  12/(-4*z + 1)^(5/2)

Sage example in ./combinat.tex, line 716::

  sage: def d(n): return derivative(C, n).subs(z=0)

Sage example in ./combinat.tex, line 721::

  sage: [ (d(n+1) / d(n)) for n in range(1,17) ]
  [2, 6, 10, 14, 18, 22, 26, 30, 34, 38, 42, 46, 50, 54, 58, 62]

Sage example in ./combinat.tex, line 737::

  sage: def c(n): return 1/n*binomial(2*(n-1),n-1)
  sage: [c(k) for k in range(1, 11)]
  [1, 1, 2, 5, 14, 42, 132, 429, 1430, 4862]
  sage: [catalan_number(k-1) for k in range(1, 11)]
  [1, 1, 2, 5, 14, 42, 132, 429, 1430, 4862]

Sage example in ./combinat.tex, line 814::

  sage: x, y, z = var('x, y, z')
  sage: P = function('P')(x, y); C = function('C')(z)
  sage: equation = P(x=z, y=C) == 0
  sage: diff(equation, z)
  diff(C(z), z)*D[1](P)(z, C(z)) + D[0](P)(z, C(z)) == 0

Sage example in ./combinat.tex, line 834::

  sage: P = y^2 - y + x; Px = diff(P, x); Py = diff(P, y)
  sage: - Px / Py
  -1/(2*y - 1)

Sage example in ./combinat.tex, line 847::

  sage: Qx = QQ['x'].fraction_field(); Qxy = Qx['y']
  sage: R = Qxy.quo(P); R
  Univariate Quotient Polynomial Ring in ybar
  over Fraction Field of Univariate Polynomial Ring in x
  over Rational Field with modulus y^2 - y + x

Sage example in ./combinat.tex, line 863::

  sage: fraction = R( - Px / Py ); fraction
  Traceback (most recent call last):
  ...
  TypeError: unable to convert -1/(2*y - 1) to an element of Univariate Quotient Polynomial Ring in ybar over Fraction Field of Univariate Polynomial Ring in x over Rational Field with modulus y^2 - y + x

Sage example in ./combinat.tex, line 869::

  sage: fraction = - R(Px) / R(Py); fraction
  (1/2/(x - 1/4))*ybar - 1/4/(x - 1/4)

Sage example in ./combinat.tex, line 877::

  sage: fraction = fraction.lift(); fraction
  (1/2/(x - 1/4))*y - 1/4/(x - 1/4)
  sage: fraction(x=z, y=C)
  2*C(z)/(4*z - 1) - 1/(4*z - 1)

Sage example in ./combinat.tex, line 894::

  sage: equadiff = diff(C,z) == fraction(x=z, y=C); equadiff
  diff(C(z), z) == 2*C(z)/(4*z - 1) - 1/(4*z - 1)
  sage: equadiff = equadiff.simplify_rational()
  sage: equadiff = equadiff * equadiff.rhs().denominator()
  sage: equadiff = equadiff - equadiff.rhs()
  sage: equadiff
  (4*z - 1)*diff(C(z), z) - 2*C(z) + 1 == 0

Sage example in ./combinat.tex, line 913::

  sage: Cf = sage.symbolic.function_factory.function('C')
  sage: equadiff.substitute_function(Cf, lambda z: s0(z=z))
  (4*z - 1)/sqrt(-4*z + 1) + sqrt(-4*z + 1) == 0

Sage example in ./combinat.tex, line 923::

  sage: Cf = sage.symbolic.function_factory.function('C')
  sage: bool(equadiff.substitute_function(Cf, lambda z: s0(z=z)))
  True

Sage example in ./combinat.tex, line 959::

  sage: def C(n): return n if n <= 1 else (4*n-6)/n * C(n-1)
  sage: [ C(i) for i in range(10) ]
  [0, 1, 1, 2, 5, 14, 42, 132, 429, 1430]

Sage example in ./combinat.tex, line 1078::

  sage: binomial(4, 2)
  6

Sage example in ./combinat.tex, line 1088::

  sage: S = Subsets([1,2,3,4], 2); S.cardinality()
  6

Sage example in ./combinat.tex, line 1097::

  sage: S.list()
  [{1, 2}, {1, 3}, {1, 4}, {2, 3}, {2, 4}, {3, 4}]
  sage: S.random_element()                 # random
  {1, 4}
  sage: S.an_element()
  {2, 3}

Sage example in ./combinat.tex, line 1118::

  sage: S.unrank(4)
  {2, 4}
  sage: S[4]
  {2, 4}

Sage example in ./combinat.tex, line 1133::

  sage: s = S([2,4]); S.rank(s)
  4

Sage example in ./combinat.tex, line 1145::

  sage: E = Set([1,2,3,4])
  sage: S = Subsets(Subsets(Subsets(E))); S.cardinality()
  2003529930406846464979072351560255750447825475569751419265016...736

Sage example in ./combinat.tex, line 1167::

  sage: S.cardinality().ndigits()
  19729

Sage example in ./combinat.tex, line 1179::

  sage: sorted(sorted(sorted(x) for x in y) for y in S.unrank(237102123) )
  [[[], [1, 2, 4], [1, 3], [1, 3, 4], [1, 4], [2], [2, 3], [2, 4], [4]],
   [[], [1, 2, 4], [1, 3], [2, 4], [3, 4]]]

Sage example in ./combinat.tex, line 1237::

  sage: P5 = Partitions(5); P5
  Partitions of the integer 5

Sage example in ./combinat.tex, line 1243::

  sage: P5.cardinality()
  7

Sage example in ./combinat.tex, line 1251::

  sage: P5.list()
  [[5], [4, 1], [3, 2], [3, 1, 1], [2, 2, 1], [2, 1, 1, 1],
   [1, 1, 1, 1, 1]]

Sage example in ./combinat.tex, line 1279::

  sage: Partitions(100000).cardinality()
  27493510569775696512677516320986352688173429315980054758203125984302147328114964173055050741660736621590157844774296248940493063070200461792764493033510116079342457190155718943509725312466108452006369558934464248716828789832182345009262853831404597021307130674510624419227311238999702284408609370935531629697851569569892196108480158600569421098519

Sage example in ./combinat.tex, line 1291::

  sage: P7 = Partitions(7); p = P7.unrank(5); p
  [4, 2, 1]

Sage example in ./combinat.tex, line 1295::

  sage: type(p)
  <class 'sage.combinat.partition.Partitions_n_with_category.element_class'>

Sage example in ./combinat.tex, line 1302::

  sage: print(p.ferrers_diagram())
  ****
  **
  *

Sage example in ./combinat.tex, line 1315::

  sage: Partition([4,2,1])
  [4, 2, 1]
  sage: P7([4,2,1])
  [4, 2, 1]

Sage example in ./combinat.tex, line 1330::

  sage: WeightedIntegerVectors(8, [2,3,5]).list()
  [[0, 1, 1], [1, 2, 0], [4, 0, 0]]

Sage example in ./combinat.tex, line 1343::

  sage: C5 = Compositions(5); C5
  Compositions of 5
  sage: C5.cardinality()
  16
  sage: C5.list()
  [[1, 1, 1, 1, 1], [1, 1, 1, 2], [1, 1, 2, 1], [1, 1, 3],
   [1, 2, 1, 1], [1, 2, 2], [1, 3, 1], [1, 4], [2, 1, 1, 1],
   [2, 1, 2], [2, 2, 1], [2, 3], [3, 1, 1], [3, 2], [4, 1], [5]]

Sage example in ./combinat.tex, line 1360::

  sage: [ Compositions(n).cardinality() for n in range(10) ]
  [1, 1, 2, 4, 8, 16, 32, 64, 128, 256]

Sage example in ./combinat.tex, line 1368::

  sage: x = var('x'); sum( x^len(c) for c in C5 )
  x^5 + 4*x^4 + 6*x^3 + 4*x^2 + x

Sage example in ./combinat.tex, line 1414::

  sage: C = IntegerRange(3, 21, 2); C
  {3, 5, ..., 19}
  sage: C.cardinality()
  9
  sage: C.list()
  [3, 5, 7, 9, 11, 13, 15, 17, 19]

Sage example in ./combinat.tex, line 1424::

  sage: C = Permutations(4); C
  Standard permutations of 4
  sage: C.cardinality()
  24
  sage: C.list()
  [[1, 2, 3, 4], [1, 2, 4, 3], [1, 3, 2, 4], [1, 3, 4, 2],
   [1, 4, 2, 3], [1, 4, 3, 2], [2, 1, 3, 4], [2, 1, 4, 3],
   [2, 3, 1, 4], [2, 3, 4, 1], [2, 4, 1, 3], [2, 4, 3, 1],
   [3, 1, 2, 4], [3, 1, 4, 2], [3, 2, 1, 4], [3, 2, 4, 1],
   [3, 4, 1, 2], [3, 4, 2, 1], [4, 1, 2, 3], [4, 1, 3, 2],
   [4, 2, 1, 3], [4, 2, 3, 1], [4, 3, 1, 2], [4, 3, 2, 1]]

Sage example in ./combinat.tex, line 1455::

  sage: C = SetPartitions([1,2,3]); C
  Set partitions of {1, 2, 3}
  sage: C.cardinality()
  5
  sage: C.list()                       # random
  [{{1, 2, 3}}, {{1}, {2, 3}}, {{1, 3}, {2}}, {{1, 2}, {3}}, {{1}, {2}, {3}}]

Sage example in ./combinat.tex, line 1466::

  sage: C = Posets(8); C
  Posets containing 8 elements
  sage: C.cardinality()
  16999

Sage example in ./combinat.tex, line 1475::

  sage: show(C.unrank(20))
  Finite poset containing 8 elements

Sage example in ./combinat.tex, line 1496::

  sage: len(list(graphs(5)))
  34

Sage example in ./combinat.tex, line 1504::

  sage: for g in graphs(5, lambda G: G.size() <= 4):
  ....:     show(g)

Sage example in ./combinat.tex, line 1528::

  sage: G = DihedralGroup(4); G
  Dihedral group of order 8 as a permutation group
  sage: G.cardinality()
  8
  sage: sorted(G.list(), key=str)
  [(), (1,2)(3,4), (1,2,3,4), (1,3), (1,3)(2,4), (1,4)(2,3), (1,4,3,2), (2,4)]

Sage example in ./combinat.tex, line 1542::

  sage: import sage.repl.display.util
  sage: sage.repl.display.util.TallListFormatter.MAX_COLUMN = 67

Sage example in ./combinat.tex, line 1547::

  sage: C = MatrixSpace(GF(2), 2); C.list()
  [
  [0 0]  [1 0]  [0 1]  [0 0]  [0 0]  [1 1]  [1 0]  [1 0]  [0 1]
  [0 0], [0 0], [0 0], [1 0], [0 1], [0 0], [1 0], [0 1], [1 0],
  <BLANKLINE>
  [0 1]  [0 0]  [1 1]  [1 1]  [1 0]  [0 1]  [1 1]
  [0 1], [1 1], [1 0], [0 1], [1 1], [1 1], [1 1]
  ]

Sage example in ./combinat.tex, line 1557::

  sage: C.cardinality()
  16

Sage example in ./combinat.tex, line 1634::

  sage: [ i^2 for i in [1, 3, 7] ]
  [1, 9, 49]

Sage example in ./combinat.tex, line 1640::

  sage: [ i^2 for i in range(1,10) ]
  [1, 4, 9, 16, 25, 36, 49, 64, 81]

Sage example in ./combinat.tex, line 1651::

  sage: [ i^2 for i in range(1,10) if is_prime(i) ]
  [4, 9, 25, 49]

Sage example in ./combinat.tex, line 1661::

  sage: [ (i,j) for i in range(1,6) for j in range(1,i) ]
  [(2, 1), (3, 1), (3, 2), (4, 1), (4, 2), (4, 3),
   (5, 1), (5, 2), (5, 3), (5, 4)]

Sage example in ./combinat.tex, line 1668::

  sage: [[binomial(n, i) for i in range(n+1)] for n in range(10)]
  [[1],
   [1, 1],
   [1, 2, 1],
   [1, 3, 3, 1],
   [1, 4, 6, 4, 1],
   [1, 5, 10, 10, 5, 1],
   [1, 6, 15, 20, 15, 6, 1],
   [1, 7, 21, 35, 35, 21, 7, 1],
   [1, 8, 28, 56, 70, 56, 28, 8, 1],
   [1, 9, 36, 84, 126, 126, 84, 36, 9, 1]]

Sage example in ./combinat.tex, line 1718::

  sage: it = (binomial(3, i) for i in range(4))

Sage example in ./combinat.tex, line 1724::

  sage: next(it)
  1
  sage: next(it)
  3
  sage: next(it)
  3
  sage: next(it)
  1

Sage example in ./combinat.tex, line 1736::

  sage: next(it)
  Traceback (most recent call last):
    ...
  StopIteration

Sage example in ./combinat.tex, line 1754::

  sage: for s in Subsets(3): s
  {}
  {1}
  {2}
  {3}
  {1, 2}
  {1, 3}
  {2, 3}
  {1, 2, 3}

Sage example in ./combinat.tex, line 1765::

  sage: [ s.cardinality() for s in Subsets(3) ]
  [0, 1, 1, 1, 2, 2, 2, 3]

Sage example in ./combinat.tex, line 1772::

  sage: sum( [ binomial(8, i) for i in range(9) ] )
  256

Sage example in ./combinat.tex, line 1784::

  sage: sum( binomial(8, i) for i in range(9) )
  256

Sage example in ./combinat.tex, line 1811::

  sage: list(binomial(8, i) for i in range(9))
  [1, 8, 28, 56, 70, 56, 28, 8, 1]
  sage: tuple(binomial(8, i) for i in range(9))
  (1, 8, 28, 56, 70, 56, 28, 8, 1)

Sage example in ./combinat.tex, line 1823::

  sage: all([True, True, True, True])
  True
  sage: all([True, False, True, True])
  False
  sage: any([False, False, False, False])
  False
  sage: any([False, False, True, False])
  True

Sage example in ./combinat.tex, line 1839::

  sage: all( is_odd(p) for p in range(3,100) if is_prime(p) )
  True

Sage example in ./combinat.tex, line 1852::

  sage: def mersenne(p): return 2^p - 1
  sage: [ is_prime(p) for p in range(1000) if is_prime(mersenne(p)) ]
  [True, True, True, True, True, True, True, True, True, True,
   True, True, True, True]

Sage example in ./combinat.tex, line 1867::

  sage: all( [ is_prime(mersenne(p)) for p in range(1000) if is_prime(p)] )
  False
  sage: all(   is_prime(mersenne(p)) for p in range(1000) if is_prime(p)  )
  False

Sage example in ./combinat.tex, line 1879::

  sage: exists( (p for p in range(1000) if is_prime(p)),
  ....:         lambda p: not is_prime(mersenne(p)) )
  (True, 11)

Sage example in ./combinat.tex, line 1895::

  sage: counter_examples = \
  ....:   (p for p in range(1000)
  ....:      if is_prime(p) and not is_prime(mersenne(p)))
  sage: next(counter_examples)
  11
  sage: next(counter_examples)
  23

Sage example in ./combinat.tex, line 1909::

  sage: cubes = [t**3 for t in range(-999,1000)]
  sage: exists([(x,y) for x in cubes for y in cubes], lambda xy: sum(xy) == 218)  # long time
  (True, (-125, 343))
  sage: exists(((x,y) for x in cubes for y in cubes), lambda xy: sum(xy) == 218)  # long time
  (True, (-125, 343))

Sage example in ./combinat.tex, line 1927::

  sage: x = var('x'); sum( x^len(s) for s in Subsets(8) )
  x^8 + 8*x^7 + 28*x^6 + 56*x^5 + 70*x^4 + 56*x^3 + 28*x^2 + 8*x + 1

Sage example in ./combinat.tex, line 1931::

  sage: sum( x^p.length() for p in Permutations(3) )
  x^3 + 2*x^2 + 2*x + 1

Sage example in ./combinat.tex, line 1940::

  sage: P = Permutations(5)
  sage: all( p in P for p in P )
  True

Sage example in ./combinat.tex, line 1945::

  sage: for p in GL(2, 2): print(p); print("-----")
  [1 0]
  [0 1]
  -----
  [0 1]
  [1 0]
  -----
  [0 1]
  [1 1]
  -----
  [1 1]
  [0 1]
  -----
  [1 1]
  [1 0]
  -----
  [1 0]
  [1 1]
  -----

Sage example in ./combinat.tex, line 1966::

  sage: for p in Partitions(3): print(p)
  [3]
  [2, 1]
  [1, 1, 1]

Sage example in ./combinat.tex, line 1987::

  sage: exists( Primes(), lambda p: not is_prime(mersenne(p)) )
  (True, 11)

Sage example in ./combinat.tex, line 2026::

  sage: import itertools

Sage example in ./combinat.tex, line 2033::

  sage: list(Permutations(3))
  [[1, 2, 3], [1, 3, 2], [2, 1, 3], [2, 3, 1], [3, 1, 2], [3, 2, 1]]

Sage example in ./combinat.tex, line 2039::

  sage: list(enumerate(Permutations(3)))
  [(0, [1, 2, 3]), (1, [1, 3, 2]), (2, [2, 1, 3]),
   (3, [2, 3, 1]), (4, [3, 1, 2]), (5, [3, 2, 1])]

Sage example in ./combinat.tex, line 2048::

  sage: list(itertools.islice(Permutations(3), 1r, 4r))
  [[1, 3, 2], [2, 1, 3], [2, 3, 1]]

Sage example in ./combinat.tex, line 2054::

  sage: list(map(lambda z: z.cycle_type(), Permutations(3)))
  [[1, 1, 1], [2, 1], [2, 1], [3], [3], [2, 1]]

Sage example in ./combinat.tex, line 2060::

  sage: list(filter(lambda z: z.has_pattern([1,2]),
  ....:                        Permutations(3)))
  [[1, 2, 3], [1, 3, 2], [2, 1, 3], [2, 3, 1], [3, 1, 2]]

Sage example in ./combinat.tex, line 2069::

  sage: list(map(attrcall("cycle_type"), Permutations(3)))
  [[1, 1, 1], [2, 1], [2, 1], [3], [3], [2, 1]]

Sage example in ./combinat.tex, line 2084::

  sage: def f(n):
  ....:    for i in range(n):
  ....:        yield i

Sage example in ./combinat.tex, line 2097::

  sage: g = f(4)
  sage: next(g)
  0
  sage: next(g)
  1
  sage: next(g)
  2
  sage: next(g)
  3

Sage example in ./combinat.tex, line 2108::

  sage: next(g)
  Traceback (most recent call last):
    ...
  StopIteration

Sage example in ./combinat.tex, line 2116::

  sage: [ x for x in f(5) ]
  [0, 1, 2, 3, 4]

Sage example in ./combinat.tex, line 2130::

  sage: def words(alphabet, l):
  ....:    if l == 0: yield []
  ....:    else:
  ....:        for word in words(alphabet, l-1):
  ....:            for l in alphabet: yield word + [l]
  sage: [ w for w in words(['a','b'], 3) ]
  [['a', 'a', 'a'], ['a', 'a', 'b'], ['a', 'b', 'a'], ['a', 'b', 'b'],
   ['b', 'a', 'a'], ['b', 'a', 'b'], ['b', 'b', 'a'], ['b', 'b', 'b']]

Sage example in ./combinat.tex, line 2142::

  sage: sum(1 for w in words(['a','b','c','d'], 10))
  1048576

Sage example in ./combinat.tex, line 2169::

  sage: def dyck_words(l):
  ....:     if l == 0: yield ''
  ....:     else:
  ....:         for k in range(l):
  ....:             for w1 in dyck_words(k):
  ....:                 for w2 in dyck_words(l-k-1):
  ....:                     yield '(' + w1 + ')' + w2

Sage example in ./combinat.tex, line 2180::

  sage: list(dyck_words(4))
  ['()()()()', '()()(())', '()(())()', '()(()())', '()((()))',
   '(())()()', '(())(())', '(()())()', '((()))()', '(()()())',
   '(()(()))', '((())())', '((()()))', '(((())))']

Sage example in ./combinat.tex, line 2188::

  sage: [ sum(1 for w in dyck_words(l)) for l in range(10) ]
  [1, 1, 2, 5, 14, 42, 132, 429, 1430, 4862]

Sage example in ./combinat.tex, line 2208::

  sage: BT = BinaryTree
  sage: BT()
  .
  sage: t = BT([BT([BT(), BT([BT(),BT()])]), BT()]); t
  [[., [., .]], .]

Sage example in ./combinat.tex, line 2261::

  sage: C = cartesian_product([Compositions(8), Permutations(20)]); C
  The Cartesian product of (Compositions of 8, Standard permutations of 20)
  sage: C.cardinality()
  311411457046609920000

Sage example in ./combinat.tex, line 2274::

  sage: C.random_element()                        # random
  ([2, 3, 2, 1], [10, 6, 11, 13, 14, 3, 4, 19, 5, 12, 7, 18, 15, 8, 20, 1, 17, 2, 9, 16])

Sage example in ./combinat.tex, line 2288::

  sage: G = DihedralGroup(4)
  sage: H = cartesian_product([G,G])
  sage: H.cardinality()
  64
  sage: H in Sets().Enumerated().Finite()
  True
  sage: H in Groups()
  True

Sage example in ./combinat.tex, line 2305::

  sage: C = DisjointUnionEnumeratedSets([Compositions(4),Permutations(3)])
  sage: C
  Disjoint union of Family (Compositions of 4, Standard permutations of 3)
  sage: C.cardinality()
  14
  sage: C.list()
  [[1, 1, 1, 1], [1, 1, 2], [1, 2, 1], [1, 3], [2, 1, 1], [2, 2], [3, 1],
  [4], [1, 2, 3], [1, 3, 2], [2, 1, 3], [2, 3, 1], [3, 1, 2], [3, 2, 1]]

Sage example in ./combinat.tex, line 2328::

  sage: F = Family(NonNegativeIntegers(), Permutations); F
  Lazy family (<class 'sage.combinat.permutation.Permutations'>(i))_{i in Non negative integers}
  sage: F.keys()
  Non negative integers
  sage: F[1000]
  Standard permutations of 1000

Sage example in ./combinat.tex, line 2339::

  sage: U = DisjointUnionEnumeratedSets(F); U
  Disjoint union of
  Lazy family (<class 'sage.combinat.permutation.Permutations'>(i))_{i in Non negative integers}

Sage example in ./combinat.tex, line 2346::

  sage: U.cardinality()
  +Infinity

Sage example in ./combinat.tex, line 2372::

  sage: U = Permutations(); U
  Standard permutations

Sage example in ./combinat.tex, line 2450::

  sage: IntegerVectors(10, 3, min_part = 2, max_part = 5,
  ....:                inner = [2, 4, 2]).list()
  [[4, 4, 2], [3, 5, 2], [3, 4, 3], [2, 5, 3], [2, 4, 4]]

Sage example in ./combinat.tex, line 2459::

  sage: Compositions(5, max_part = 3,
  ....:              min_length = 2, max_length = 3).list()
  [[3, 2], [3, 1, 1], [2, 3], [2, 2, 1], [2, 1, 2], [1, 3, 1],
   [1, 2, 2], [1, 1, 3]]

Sage example in ./combinat.tex, line 2467::

  sage: Partitions(5, max_slope = -1).list()
  [[5], [4, 1], [3, 2]]

Sage example in ./combinat.tex, line 2484::

  sage: IntegerListsLex(10, length=3, min_part = 2, max_part = 5,
  ....:                 floor = [2, 4, 2]).list()
  [[4, 4, 2], [3, 5, 2], [3, 4, 3], [2, 5, 3], [2, 4, 4]]

Sage example in ./combinat.tex, line 2489::

  sage: IntegerListsLex(5, min_part = 1, max_part = 3,
  ....:                 min_length = 2, max_length = 3).list()
  [[3, 2], [3, 1, 1], [2, 3], [2, 2, 1], [2, 1, 2], [1, 3, 1],
   [1, 2, 2], [1, 1, 3]]

Sage example in ./combinat.tex, line 2495::

  sage: IntegerListsLex(5, min_part = 1, max_slope = -1).list()
  [[5], [4, 1], [3, 2]]

Sage example in ./combinat.tex, line 2499::

  sage: list(Compositions(5, max_length=2))
  [[5], [4, 1], [3, 2], [2, 3], [1, 4]]

Sage example in ./combinat.tex, line 2503::

  sage: list(IntegerListsLex(5, max_length=2, min_part=1))
  [[5], [4, 1], [3, 2], [2, 3], [1, 4]]

Sage example in ./combinat.tex, line 2625::

  sage: A = random_matrix(ZZ, 6, 3, x=7)
  sage: L = LatticePolytope(A.rows())
  sage: L.points()                               # random
  M(1, 4, 3),
  M(6, 4, 1),
  ...
  M(3, 5, 5)
  in 3-d lattice M
  sage: L.points().cardinality()                 # random
  23

Sage example in ./combinat.tex, line 2637::

  sage: L.points()
  M(...),
  M(...),
  ...
  M(...)
  in 3-d lattice M

Sage example in ./combinat.tex, line 2647::

  sage: L.plot3d()
  Graphics3d Object

Sage example in ./combinat.tex, line 2688::

  sage: from sage.combinat.species.library import *
  sage: o = var('o')

Sage example in ./combinat.tex, line 2697::

  sage: BT = CombinatorialSpecies(min=1)
  sage: Leaf =  SingletonSpecies()
  sage: BT.define( Leaf + (BT*BT) )

Sage example in ./combinat.tex, line 2707::

  sage: BT5 = BT.isotypes([o]*5); BT5.cardinality()
  14
  sage: BT5.list()
  [o*(o*(o*(o*o))), o*(o*((o*o)*o)), o*((o*o)*(o*o)), o*((o*(o*o))*o),
   o*(((o*o)*o)*o), (o*o)*(o*(o*o)), (o*o)*((o*o)*o), (o*(o*o))*(o*o),
   ((o*o)*o)*(o*o), (o*(o*(o*o)))*o, (o*((o*o)*o))*o, ((o*o)*(o*o))*o,
   ((o*(o*o))*o)*o, (((o*o)*o)*o)*o]

Sage example in ./combinat.tex, line 2727::

  sage: g = BT.isotype_generating_series(); g
  z + z^2 + 2*z^3 + 5*z^4 + 14*z^5 + 42*z^6 + 132*z^7 + O(z^8)

Sage example in ./combinat.tex, line 2733::

  sage: g[100]
  227508830794229349661819540395688853956041682601541047340

Sage example in ./combinat.tex, line 2743::

  sage: Eps = EmptySetSpecies(); Z0 = SingletonSpecies()
  sage: Z1 = Eps*SingletonSpecies()
  sage: FW  = CombinatorialSpecies()
  sage: FW.define(Eps + Z0*FW  +  Z1*Eps + Z1*Z0*FW)

Sage example in ./combinat.tex, line 2752::

  sage: L = FW.isotype_generating_series()[:15]; L
  [1, 2, 3, 5, 8, 13, 21, 34, 55, 89, 144, 233, 377, 610, 987]

Sage example in ./combinat.tex, line 2769::

  sage: FW3 = FW.isotypes([o]*3)
  sage: FW3.list()
  [o*(o*(o*{})), o*(o*(({}*o)*{})), o*((({}*o)*o)*{}),
   (({}*o)*o)*(o*{}), (({}*o)*o)*(({}*o)*{})]

Sage example in ./combinat.tex, line 3007::

  sage: [len(list(graphs(n, property = lambda G: G.is_planar())))
  ....:  for n in range(7)]
  [1, 1, 2, 4, 11, 33, 142]

Sage example in ./combinat.tex, line 3066::

  sage: V = [1,2,3,4]
  sage: F = Subsets(V, 2); F.list()
  [{1, 2}, {1, 3}, {1, 4}, {2, 3}, {2, 4}, {3, 4}]

Sage example in ./combinat.tex, line 3072::

  sage: S = SymmetricGroup(V)

Sage example in ./combinat.tex, line 3077::

  sage: def on_pair(sigma, pair):
  ....:     return Set(sigma(i) for i in pair)
  sage: def on_pairs(sigma):
  ....:     return [on_pair(sigma, e) for e in F]

Sage example in ./combinat.tex, line 3086::

  sage: sigma = S([(1,2,3,4)]); sigma
  (1,2,3,4)
  sage: for e in F: print((e, on_pair(sigma, e)))
  ({1, 2}, {2, 3})
  ({1, 3}, {2, 4})
  ({1, 4}, {1, 2})
  ({2, 3}, {3, 4})
  ({2, 4}, {1, 3})
  ({3, 4}, {1, 4})
  sage: on_pairs(sigma)
  [{2, 3}, {2, 4}, {1, 2}, {3, 4}, {1, 3}, {1, 4}]

Sage example in ./combinat.tex, line 3102::

  sage: G = PermutationGroup([ on_pairs(sigma) for sigma in S.gens() ],
  ....:                      domain=F)

Sage example in ./combinat.tex, line 3109::

  sage: Z = G.cycle_index(); Z
  1/24*p[1, 1, 1, 1, 1, 1] + 3/8*p[2, 2, 1, 1] + 1/3*p[3, 3] + 1/4*p[4, 2]

Sage example in ./combinat.tex, line 3117::

  sage: sorted(sigma for sigma in G if sigma.cycle_type() == [4,2])
  [({1,2},{1,3},{3,4},{2,4})({1,4},{2,3}),
   ({1,2},{1,4},{3,4},{2,3})({1,3},{2,4}),
   ({1,2},{2,3},{3,4},{1,4})({1,3},{2,4}),
   ({1,2},{2,4},{3,4},{1,3})({1,4},{2,3}),
   ({1,2},{3,4})({1,3},{1,4},{2,4},{2,3}),
   ({1,2},{3,4})({1,3},{2,3},{2,4},{1,4})]

Sage example in ./combinat.tex, line 3136::

  sage: q,t = QQ['q,t'].gens()
  sage: p = Z.expand(2, [q,t]); p
  q^6 + q^5*t + 2*q^4*t^2 + 3*q^3*t^3 + 2*q^2*t^4 + q*t^5 + t^6

Sage example in ./combinat.tex, line 3146::

  sage: p(q=1,t=1)
  11

Sage example in ./combinat.tex, line 3159::

  sage: q = var('q')
  sage: H = sum( c * prod( 1/(1-q^k) for k in partition )
  ....:          for partition, c in Z )
  sage: H
  1/3/(q^3 - 1)^2 + 1/4/((q^4 - 1)*(q^2 - 1))
  + 3/8/((q^2 - 1)^2*(q - 1)^2) + 1/24/(q - 1)^6

Sage example in ./combinat.tex, line 3171::

  sage: H.series(q)
  1 + 1*q + 3*q^2 + 6*q^3 + 11*q^4 + 18*q^5 + 32*q^6 + 48*q^7
  + 75*q^8 + 111*q^9 + 160*q^10 + 224*q^11 + 313*q^12 + 420*q^13
  + 562*q^14 + 738*q^15 + 956*q^16 + 1221*q^17 + 1550*q^18 + 1936*q^19
  + Order(q^20)

Sage example in ./combinat.tex, line 3185::

  sage: n = 10
  sage: V = range(1,n+1)
  sage: F = Subsets(V, 2)
  sage: S = SymmetricGroup(V)
  sage: G = PermutationGroup([ on_pairs(sigma) for sigma in S.gens() ],
  ....:                      domain=F)
  sage: q,t = QQ['q,t'].gens()
  sage: Z = G.cycle_index()
  sage: Z.expand(2, [q,t])(q=1,t=1)
  12005168

Sage example in ./combinat.tex, line 3202::

  sage: n = 20
  sage: V = range(1,n+1)
  sage: F = Subsets(V, 2)
  sage: S = SymmetricGroup(V)
  sage: CC = S.conjugacy_classes(); CC  # long time
  [...
   Conjugacy class of cycle type [19, 1] in Symmetric group of order 20! as a permutation group,
   Conjugacy class of cycle type [20] in Symmetric group of order 20! as a permutation group]

Sage example in ./combinat.tex, line 3214::

  sage: p = SymmetricFunctions(QQ).powersum()
  sage: G = PermutationGroup([ on_pairs(sigma) for sigma in S.gens() ],
  ....:                      domain=F)
  sage: Z = p.sum_of_terms([G(on_pairs(c.representative())).cycle_type(),  # long time
  ....:                     c.cardinality()]
  ....:                    for c in CC) / factorial(n)
  sage: Z.expand(2, [q,t])(q=1,t=1)  # long time
  645490122795799841856164638490742749440
"""



# sage_setup: distribution = sagemath-repl
"""
This file (./calculus_doctest.sage) was *autogenerated* from ./calculus.tex,
with sagetex.sty version 2011/05/27 v2.3.1.
It contains the contents of all the sageexample environments from this file.
You should be able to doctest this file with:
sage -t ./calculus_doctest.sage
It is always safe to delete this file; it is not used in typesetting your
document.

Sage example in ./calculus.tex, line 76::

  sage: bool(arctan(1+abs(x)) == pi/2 - arctan(1/(1+abs(x))))
  False

Sage example in ./calculus.tex, line 121::

  sage: a, x = var('a, x'); y = cos(x+a) * (x+1); y
  (x + 1)*cos(a + x)
  sage: y.subs(a=-x); y.subs(x=pi/2, a=pi/3); y.subs(x=0.5, a=2.3)
  x + 1
  -1/4*sqrt(3)*(pi + 2)
  -1.41333351100299
  sage: y(a=-x); y(x=pi/2, a=pi/3); y(x=0.5, a=2.3)
  x + 1
  -1/4*sqrt(3)*(pi + 2)
  -1.41333351100299

Sage example in ./calculus.tex, line 143::

  sage: x, y, z = var('x, y, z') ; q = x*y + y*z + z*x
  sage: bool(q(x=y, y=z, z=x) == q), bool(q(z=y)(y=x) == 3*x^2)
  (True, True)

Sage example in ./calculus.tex, line 155::

  sage: y, z = var('y, z'); f = x^3 + y^2 + z
  sage: f.substitute(x^3 == y^2, z==1)
  2*y^2 + 1

Sage example in ./calculus.tex, line 176::

  sage: f(x)=(2*x+1)^3 ; f(-3)
  -125
  sage: f.expand()
  x |--> 8*x^3 + 12*x^2 + 6*x + 1

Sage example in ./calculus.tex, line 193::

  sage: y = var('y'); u = sin(x) + x*cos(y)
  sage: v = u.function(x, y); v
  (x, y) |--> x*cos(y) + sin(x)
  sage: w(x, y) = u; w
  (x, y) |--> x*cos(y) + sin(x)

Sage example in ./calculus.tex, line 240::

  sage: x, y = SR.var('x,y')
  sage: p = (x+y)*(x+1)^2
  sage: p2 = p.expand(); p2
  x^3 + x^2*y + 2*x^2 + 2*x*y + x + y

Sage example in ./calculus.tex, line 251::

  sage: p2.collect(x)
  x^3 + x^2*(y + 2) + x*(2*y + 1) + y

Sage example in ./calculus.tex, line 260::

  sage: ((x+y+sin(x))^2).expand().collect(sin(x))
  x^2 + 2*x*y + y^2 + 2*(x + y)*sin(x) + sin(x)^2

Sage example in ./calculus.tex, line 416::

  sage: (x^x/x).simplify()
  x^(x - 1)

Sage example in ./calculus.tex, line 426::

  sage: f = (e^x-1) / (1+e^(x/2)); f.canonicalize_radical()
  e^(1/2*x) - 1

Sage example in ./calculus.tex, line 435::

  sage: f = cos(x)^6 + sin(x)^6 + 3 * sin(x)^2 * cos(x)^2
  sage: f.simplify_trig()
  1

Sage example in ./calculus.tex, line 447::

  sage: f = cos(x)^6; f.reduce_trig()
  1/32*cos(6*x) + 3/16*cos(4*x) + 15/32*cos(2*x) + 5/16
  sage: f = sin(5 * x); f.expand_trig()
  5*cos(x)^4*sin(x) - 10*cos(x)^2*sin(x)^3 + sin(x)^5

Sage example in ./calculus.tex, line 482::

  sage: n = var('n'); f = factorial(n+1)/factorial(n)
  sage: f.simplify_factorial()
  n + 1

Sage example in ./calculus.tex, line 502::

  sage: f = sqrt(abs(x)^2); f.canonicalize_radical()
  abs(x)
  sage: f = log(x*y); f.canonicalize_radical()
  log(x) + log(y)

Sage example in ./calculus.tex, line 592::

  sage: assume(x > 0); bool(sqrt(x^2) == x)
  True
  sage: forget(x > 0); bool(sqrt(x^2) == x)
  False
  sage: n = var('n'); assume(n, 'integer'); sin(n*pi)
  0

Sage example in ./calculus.tex, line 600::

  sage: forget(n, 'integer');

Sage example in ./calculus.tex, line 690::

  sage: a = var('a')
  sage: c = (a+1)^2 - (a^2+2*a+1)

Sage example in ./calculus.tex, line 700::

  sage: eq =  c * x == 0

Sage example in ./calculus.tex, line 707::

  sage: eq2 = eq / c; eq2
  x == 0
  sage: solve(eq2, x)
  [x == 0]

Sage example in ./calculus.tex, line 715::

  sage: solve(eq, x)
  [x == x]

Sage example in ./calculus.tex, line 725::

  sage: expand(c)
  0

Sage example in ./calculus.tex, line 738::

  sage: c = cos(a)^2 + sin(a)^2 - 1
  sage: eq = c*x == 0
  sage: solve(eq, x)
  [x == 0]

Sage example in ./calculus.tex, line 750::

  sage: c.simplify_trig()
  0
  sage: c.is_zero()
  True

Sage example in ./calculus.tex, line 839::

  sage: z, phi = var('z, phi')
  sage: eq =  z**2 - 2/cos(phi)*z + 5/cos(phi)**2 - 4 == 0; eq
  z^2 - 2*z/cos(phi) + 5/cos(phi)^2 - 4 == 0

Sage example in ./calculus.tex, line 852::

  sage: eq.lhs()
  z^2 - 2*z/cos(phi) + 5/cos(phi)^2 - 4
  sage: eq.rhs()
  0

Sage example in ./calculus.tex, line 861::

  sage: solve(eq, z)
  [z == -(2*sqrt(cos(phi)^2 - 1) - 1)/cos(phi),
   z ==  (2*sqrt(cos(phi)^2 - 1) + 1)/cos(phi)]

Sage example in ./calculus.tex, line 871::

  sage: y = var('y'); solve(y^7==y, y)
  [y == 1/2*I*sqrt(3) + 1/2, y == 1/2*I*sqrt(3) - 1/2, y == -1,
   y == -1/2*I*sqrt(3) - 1/2, y == -1/2*I*sqrt(3) + 1/2, y == 1, y == 0]

Sage example in ./calculus.tex, line 880::

  sage: solve(x^2-1, x, solution_dict=True)
  [{x: -1}, {x: 1}]

Sage example in ./calculus.tex, line 894::

  sage: solve([x+y == 3, 2*x+2*y == 6], x, y)
  [[x == -r1 + 3, y == r1]]

Sage example in ./calculus.tex, line 910::

  sage: solve([cos(x)*sin(x) == 1/2, x+y == 0], x, y)
  [[x == 1/4*pi + pi*z..., y == -1/4*pi - pi*z...]]

Sage example in ./calculus.tex, line 920::

  sage: solve(x^2+x-1 > 0, x)
  [[x < -1/2*sqrt(5) - 1/2], [x > 1/2*sqrt(5) - 1/2]]

Sage example in ./calculus.tex, line 943::

  sage: x, y, z = var('x, y, z')
  sage: solve([x^2 * y * z == 18, x * y^3 * z == 24,\
  ....:        x * y * z^4 == 6], x, y, z)
  [[x == 3, y == 2, z == 1],
   [x == (1.3372150673296... - 2.685489874065...*I),
    y == (-1.7004342714592... + 1.0528643257547...*I),
    z == (0.93247222940435... - 0.36124166618715...*I)], ...]

Sage example in ./calculus.tex, line 975::

  sage: expr = sin(x) + sin(2 * x) + sin(3 * x)
  sage: solve(expr, x)
  [sin(3*x) == -sin(2*x) - sin(x)]

Sage example in ./calculus.tex, line 983::

  sage: find_root(expr, 0.1, pi)  # abs tol 1e-12
  2.0943951023931957

Sage example in ./calculus.tex, line 989::

  sage: f = expr.simplify_trig(); f
  2*(2*cos(x)^2 + cos(x))*sin(x)
  sage: solve(f, x)
  [x == 0, x == 2/3*pi, x == 1/2*pi]

Sage example in ./calculus.tex, line 1022::

  sage: (x^3+2*x+1).roots(x)
  [(-1/2*(1/18*sqrt(59)*sqrt(3) - 1/2)^(1/3)*(I*sqrt(3) + 1)
     - 1/3*(I*sqrt(3) - 1)/(1/18*sqrt(59)*sqrt(3) - 1/2)^(1/3), 1),
    (-1/2*(1/18*sqrt(59)*sqrt(3) - 1/2)^(1/3)*(-I*sqrt(3) + 1)
     - 1/3*(-I*sqrt(3) - 1)/(1/18*sqrt(59)*sqrt(3) - 1/2)^(1/3), 1),
    ((1/18*sqrt(59)*sqrt(3) - 1/2)^(1/3)
     - 2/3/(1/18*sqrt(59)*sqrt(3) - 1/2)^(1/3), 1)]

Sage example in ./calculus.tex, line 1058::

  sage: (x^3+2*x+1).roots(x, ring=RR)
  [(-0.453397651516404, 1)]

Sage example in ./calculus.tex, line 1062::

  sage: (x^3+2*x+1).roots(x, ring=CC)
  [(-0.453397651516404, 1),
   (0.226698825758202 - 1.46771150871022*I, 1),
   (0.226698825758202 + 1.46771150871022*I, 1)]

Sage example in ./calculus.tex, line 1086::

  sage: solve(x^(1/x)==(1/x)^x, x)
  [(1/x)^x == x^(1/x)]

Sage example in ./calculus.tex, line 1124::

  sage: y = function('y')(x)
  sage: desolve(diff(y,x,x) + x*diff(y,x) + y == 0, y, [0,0,1])
  -1/2*I*sqrt(2)*sqrt(pi)*erf(1/2*I*sqrt(2)*x)*e^(-1/2*x^2)

Sage example in ./calculus.tex, line 1171::

  sage: k, n = var('k, n')
  sage: sum(k, k, 1, n).factor()
  1/2*(n + 1)*n

Sage example in ./calculus.tex, line 1179::

  sage: n, k, y = var('n, k, y')
  sage: sum(binomial(n,k) * x^k * y^(n-k), k, 0, n)
  (x + y)^n

Sage example in ./calculus.tex, line 1189::

  sage: k, n = var('k, n')
  sage: sum(binomial(n,k), k, 0, n),\
  ....: sum(k * binomial(n, k), k, 0, n),\
  ....: sum((-1)^k*binomial(n,k), k, 0, n)
  (2^n, 2^(n - 1)*n, 0)

Sage example in ./calculus.tex, line 1199::

  sage: a, q, k, n = var('a, q, k, n')
  sage: sum(a*q^k, k, 0, n)
  (a*q^(n + 1) - a)/(q - 1)

Sage example in ./calculus.tex, line 1212::

  sage: assume(abs(q) < 1)
  sage: sum(a*q^k, k, 0, infinity)
  -a/(q - 1)

Sage example in ./calculus.tex, line 1218::

  sage: forget(); assume(q > 1); sum(a*q^k, k, 0, infinity)
  Traceback (most recent call last):
  ...
  ValueError: Sum is divergent.

Sage example in ./calculus.tex, line 1300::

  sage: limit((x**(1/3) - 2) / ((x + 19)**(1/3) - 3), x = 8)
  9/4
  sage: f(x) = (cos(pi/4-x)-tan(x))/(1-sin(pi/4 + x))
  sage: limit(f(x), x = pi/4)
  Infinity

Sage example in ./calculus.tex, line 1317::

  sage: limit(f(x), x = pi/4, dir='minus')
  +Infinity
  sage: limit(f(x), x = pi/4, dir='plus')
  -Infinity

Sage example in ./calculus.tex, line 1368::

  sage: u(n) = n^100 / 100^n
  sage: u(1.);u(2.);u(3.);u(4.);u(5.);u(6.);u(7.);u(8.);u(9.);u(10.)
  0.0100000000000000
  1.26765060022823e26
  5.15377520732011e41
  1.60693804425899e52
  7.88860905221012e59
  6.53318623500071e65
  3.23447650962476e70
  2.03703597633449e74
  2.65613988875875e77
  1.00000000000000e80

Sage example in ./calculus.tex, line 1389::

  sage: plot(u(x), x, 1, 40)
  Graphics object consisting of 1 graphics primitive

Sage example in ./calculus.tex, line 1407::

  sage: v(x) = diff(u(x), x); sol = solve(v(x) == 0, x); sol
  [x == 50/log(10), x == 0]
  sage: floor(sol[0].rhs())
  21

Sage example in ./calculus.tex, line 1420::

  sage: limit(u(n), n=infinity)
  0
  sage: n0 = find_root(u(n) - 1e-8 == 0, 22, 1000); n0
  105.07496210187252

Sage example in ./calculus.tex, line 1502::

  sage: ((1+arctan(x))^(1/x)).series(x==0, 3)
  (e) + (-1/2*e)*x + (1/8*e)*x^2 + Order(x^3)

Sage example in ./calculus.tex, line 1507::

  sage: (ln(2*sin(x))).series(x==pi/6, 3)
  (sqrt(3))*(-1/6*pi + x) + (-2)*(-1/6*pi + x)^2
  + Order(-1/216*(pi - 6*x)^3)

Sage example in ./calculus.tex, line 1520::

  sage: (ln(2*sin(x))).series(x==pi/6, 3).truncate()
  -1/18*(pi - 6*x)^2 - 1/6*sqrt(3)*(pi - 6*x)

Sage example in ./calculus.tex, line 1537::

  sage: taylor((x**3+x)**(1/3) - (x**3-x)**(1/3), x, infinity, 2)
  2/3/x

Sage example in ./calculus.tex, line 1577::

  sage: tan(4*arctan(1/5)).simplify_trig()
  120/119
  sage: tan(pi/4+arctan(1/239)).simplify_trig()
  120/119

Sage example in ./calculus.tex, line 1591::

  sage: f = arctan(x).series(x, 10); f
  1*x + (-1/3)*x^3 + 1/5*x^5 + (-1/7)*x^7 + 1/9*x^9 + Order(x^10)
  sage: (16*f.subs(x==1/5) - 4*f.subs(x==1/239)).n(); pi.n()
  3.14159268240440
  3.14159265358979

Sage example in ./calculus.tex, line 1662::

  sage: k = var('k')
  sage: sum(1/k^2, k, 1, infinity),\
  ....: sum(1/k^4, k, 1, infinity),\
  ....: sum(1/k^5, k, 1, infinity)
  (1/6*pi^2, 1/90*pi^4, zeta(5))

Sage example in ./calculus.tex, line 1689::

  sage: s = 2*sqrt(2)/9801*(sum((factorial(4*k)) * (1103+26390*k) /
  ....:     ((factorial(k)) ^ 4 * 396 ^ (4 * k)) for k in (0..11)))
  sage: (1/s).n(digits=100)
  3.141592653589793238462643383279502884197169399375105820974...
  sage: (pi-1/s).n(digits=100).n()
  -4.36415445739398e-96

Sage example in ./calculus.tex, line 1722::

  sage: n = var('n'); u = sin(pi*(sqrt(4*n^2+1)-2*n))
  sage: taylor(u, n, infinity, 3)
  1/4*pi/n - 1/384*(6*pi + pi^3)/n^3

Sage example in ./calculus.tex, line 1762::

  sage: diff(sin(x^2), x)
  2*x*cos(x^2)
  sage: function('f')(x); function('g')(x); diff(f(g(x)), x)
  f(x)
  g(x)
  D[0](f)(g(x))*diff(g(x), x)
  sage: diff(ln(f(x)), x)
  diff(f(x), x)/f(x)

Sage example in ./calculus.tex, line 1780::

  sage: f(x,y) = x*y + sin(x^2) + e^(-x); derivative(f, x)
  (x, y) |--> 2*x*cos(x^2) + y - e^(-x)
  sage: derivative(f, y)
  (x, y) |--> x

Sage example in ./calculus.tex, line 1803::

  sage: x, y = var('x, y'); f = ln(x**2+y**2) / 2
  sage: delta = diff(f,x,2) + diff(f,y,2)
  sage: delta.simplify_rational()
  0

Sage example in ./calculus.tex, line 1854::

  sage: sin(x).integral(x, 0, pi/2)
  1
  sage: integrate(1/(1+x^2), x)
  arctan(x)
  sage: integrate(1/(1+x^2), x, -infinity, infinity)
  pi
  sage: integrate(exp(-x**2), x, 0, infinity)
  1/2*sqrt(pi)

Sage example in ./calculus.tex, line 1864::

  sage: integrate(exp(-x), x, -infinity, infinity)
  Traceback (most recent call last):
  ...
  ValueError: Integral is divergent.

Sage example in ./calculus.tex, line 1878::

  sage: u = var('u'); f = x * cos(u) / (u^2 + x^2)
  sage: assume(x>0); f.integrate(u, 0, infinity)
  1/2*pi*e^(-x)
  sage: forget(); assume(x<0); f.integrate(u, 0, infinity)
  -1/2*pi*e^x

Sage example in ./calculus.tex, line 1904::

  sage: integral_numerical(sin(x)/x, 0, 1)   # abs tol 1e-12
  (0.946083070367183, 1.0503632079297087e-14)
  sage: g = integrate(exp(-x**2), x, 0, infinity)
  sage: g, g.n()                             # abs tol 1e-12
  (1/2*sqrt(pi), 0.886226925452758)
  sage: approx = integral_numerical(exp(-x**2), 0, infinity)
  sage: approx                               # abs tol 1e-12
  (0.8862269254527568, 1.714774436012769e-08)
  sage: approx[0]-g.n()                      # abs tol 1e-12
  -1.11022302462516e-15

Sage example in ./calculus.tex, line 2228::

  sage: A = matrix(QQ, [[1,2],[3,4]]); A
  [1 2]
  [3 4]

Sage example in ./calculus.tex, line 2468::

  sage: A = matrix(QQ, [[2,4,3],[-4,-6,-3],[3,3,1]])
  sage: A.characteristic_polynomial()
  x^3 + 3*x^2 - 4
  sage: A.eigenvalues()
  [1, -2, -2]
  sage: A.minimal_polynomial().factor()
  (x - 1) * (x + 2)^2

Sage example in ./calculus.tex, line 2487::

  sage: A.eigenvectors_right()
  [(1, [(1, -1, 1)], 1), (-2, [(1, -1, 0)], 2)]

Sage example in ./calculus.tex, line 2499::

  sage: A.jordan_form(transformation=True)
  (
  [ 1| 0  0]
  [--+-----]  [ 1  1  1]
  [ 0|-2  1]  [-1 -1  0]
  [ 0| 0 -2], [ 1  0 -1]
  )

Sage example in ./calculus.tex, line 2533::

  sage: A = matrix(QQ, [[1,-1/2],[-1/2,-1]])
  sage: A.jordan_form()
  Traceback (most recent call last):
  ...
  RuntimeError: Some eigenvalue does not exist in Rational Field.

Sage example in ./calculus.tex, line 2543::

  sage: A = matrix(QQ, [[1,-1/2],[-1/2,-1]])
  sage: A.minimal_polynomial()
  x^2 - 5/4

Sage example in ./calculus.tex, line 2557::

  sage: R = QQ[sqrt(5)]
  sage: A = A.change_ring(R)
  sage: A.jordan_form(transformation=True, subdivide=False)
  (
  [ 1/2*sqrt5          0]  [         1          1]
  [         0 -1/2*sqrt5], [-sqrt5 + 2  sqrt5 + 2]
  )

Sage example in ./calculus.tex, line 2597::

  sage: K.<sqrt2> = NumberField(x^2 - 2)
  sage: L.<sqrt3> = K.extension(x^2 - 3)
  sage: A = matrix(L, [[2, sqrt2*sqrt3, sqrt2],  \
  ....:                [sqrt2*sqrt3, 3, sqrt3],  \
  ....:                [sqrt2, sqrt3, 1]])
  sage: A.jordan_form(transformation=True)
  (
  [6|0|0]
  [-+-+-]
  [0|0|0]  [              1               1               0]
  [-+-+-]  [1/2*sqrt2*sqrt3               0               1]
  [0|0|0], [      1/2*sqrt2          -sqrt2          -sqrt3]
  )
"""
